==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CategoryToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryToolTipLayerDescription } from "./CategoryToolTipLayerDescription";
/**
 * @hidden
 */
var CategoryToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategoryToolTipLayerDescriptionMetadata, _super);
    function CategoryToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryToolTipLayerDescriptionMetadata.b = function (a) {
        if (CategoryToolTipLayerDescriptionMetadata.a == null) {
            CategoryToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryToolTipLayerDescriptionMetadata.c(CategoryToolTipLayerDescriptionMetadata.a);
        }
        if (a.k(CategoryToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.aa(CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
    };
    CategoryToolTipLayerDescriptionMetadata.d = function (a) {
        CategoryToolTipLayerDescriptionMetadata.b(a);
        a.ac("CategoryToolTipLayer", function () { return new CategoryToolTipLayerDescription(); });
        a.ab("CategoryToolTipLayer", CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.$t = markType(CategoryToolTipLayerDescriptionMetadata, 'CategoryToolTipLayerDescriptionMetadata');
    CategoryToolTipLayerDescriptionMetadata.a = null;
    return CategoryToolTipLayerDescriptionMetadata;
}(Base));
export { CategoryToolTipLayerDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/CategoryToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryToolTipLayerDescription } from "./CategoryToolTipLayerDescription";
/**
 * @hidden
 */
var CategoryToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryToolTipLayerDescriptionMetadata, _super);
    function CategoryToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryToolTipLayerDescriptionMetadata.b = function (a) {
        if (CategoryToolTipLayerDescriptionMetadata.a == null) {
            CategoryToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryToolTipLayerDescriptionMetadata.c(CategoryToolTipLayerDescriptionMetadata.a);
        }
        if (a.k(CategoryToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.ac(CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
    };
    CategoryToolTipLayerDescriptionMetadata.d = function (a) {
        CategoryToolTipLayerDescriptionMetadata.b(a);
        a.ae("CategoryToolTipLayer", function () { return new CategoryToolTipLayerDescription(); });
        a.ad("CategoryToolTipLayer", CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.$t = markType(CategoryToolTipLayerDescriptionMetadata, 'CategoryToolTipLayerDescriptionMetadata');
    CategoryToolTipLayerDescriptionMetadata.a = null;
    return CategoryToolTipLayerDescriptionMetadata;
}(Base));
export { CategoryToolTipLayerDescriptionMetadata };
